@@ -249,7 +249,7 @@ If CREATE is non-nil then create the folder if necessary."
       ;; typo, or just the user want a new folder, let the user decide
       ;; how to deal with it.
       (error
-       (let ((response (read-char-choice
+       (let ((response (notmuch-read-char-choice
 			"Insert failed: (r)etry, (c)reate folder, (i)gnore, or  (e)dit the header? "
 			'(?r ?c ?i ?e))))
 	 (case response
@@ -335,7 +335,7 @@ if needed."
     ;; fix it in some way.
     (let* ((prompt (format "Fcc %s is not a maildir: (r)etry, (c)reate folder, (i)gnore, or  (e)dit the header? "
 			   fcc-header))
-	    (response (read-char-choice prompt '(?r ?c ?i ?e))))
+	    (response (notmuch-read-char-choice prompt '(?r ?c ?i ?e))))
 	 (case response
 	       (?r (notmuch-maildir-fcc-file-fcc fcc-header))
 	       (?c (if (file-writable-p fcc-header)
